searchData={"items":[{"type":"module","title":"Twm","doc":"TWM - A Tailwind CSS class merger for Elixir.\n\nMerges Tailwind CSS classes without style conflicts by intelligently\nhandling conflicting utilities.","ref":"Twm.html"},{"type":"function","title":"Twm.is_any/0","doc":"See  Twm.Validators.any?/0 .","ref":"Twm.html#is_any/0"},{"type":"function","title":"Twm.is_any/1","doc":"See  Twm.Validators.any?/1 .","ref":"Twm.html#is_any/1"},{"type":"function","title":"Twm.is_any_non_arbitrary/1","doc":"See  Twm.Validators.is_any_non_arbitrary/1 .","ref":"Twm.html#is_any_non_arbitrary/1"},{"type":"function","title":"Twm.is_arbitrary_image/1","doc":"See  Twm.Validators.is_arbitrary_image/1 .","ref":"Twm.html#is_arbitrary_image/1"},{"type":"function","title":"Twm.is_arbitrary_length/1","doc":"See  Twm.Validators.is_arbitrary_length/1 .","ref":"Twm.html#is_arbitrary_length/1"},{"type":"function","title":"Twm.is_arbitrary_number/1","doc":"See  Twm.Validators.is_arbitrary_number/1 .","ref":"Twm.html#is_arbitrary_number/1"},{"type":"function","title":"Twm.is_arbitrary_position/1","doc":"See  Twm.Validators.is_arbitrary_position/1 .","ref":"Twm.html#is_arbitrary_position/1"},{"type":"function","title":"Twm.is_arbitrary_shadow/1","doc":"See  Twm.Validators.is_arbitrary_shadow/1 .","ref":"Twm.html#is_arbitrary_shadow/1"},{"type":"function","title":"Twm.is_arbitrary_size/1","doc":"See  Twm.Validators.is_arbitrary_size/1 .","ref":"Twm.html#is_arbitrary_size/1"},{"type":"function","title":"Twm.is_arbitrary_value/1","doc":"See  Twm.Validators.is_arbitrary_value/1 .","ref":"Twm.html#is_arbitrary_value/1"},{"type":"function","title":"Twm.is_arbitrary_variable/1","doc":"See  Twm.Validators.is_arbitrary_variable/1 .","ref":"Twm.html#is_arbitrary_variable/1"},{"type":"function","title":"Twm.is_arbitrary_variable_family_name/1","doc":"See  Twm.Validators.is_arbitrary_variable_family_name/1 .","ref":"Twm.html#is_arbitrary_variable_family_name/1"},{"type":"function","title":"Twm.is_arbitrary_variable_image/1","doc":"See  Twm.Validators.is_arbitrary_variable_image/1 .","ref":"Twm.html#is_arbitrary_variable_image/1"},{"type":"function","title":"Twm.is_arbitrary_variable_length/1","doc":"See  Twm.Validators.is_arbitrary_variable_length/1 .","ref":"Twm.html#is_arbitrary_variable_length/1"},{"type":"function","title":"Twm.is_arbitrary_variable_position/1","doc":"See  Twm.Validators.is_arbitrary_variable_position/1 .","ref":"Twm.html#is_arbitrary_variable_position/1"},{"type":"function","title":"Twm.is_arbitrary_variable_shadow/1","doc":"See  Twm.Validators.is_arbitrary_variable_shadow/1 .","ref":"Twm.html#is_arbitrary_variable_shadow/1"},{"type":"function","title":"Twm.is_arbitrary_variable_size/1","doc":"See  Twm.Validators.is_arbitrary_variable_size/1 .","ref":"Twm.html#is_arbitrary_variable_size/1"},{"type":"function","title":"Twm.is_fraction/1","doc":"See  Twm.Validators.is_fraction/1 .","ref":"Twm.html#is_fraction/1"},{"type":"function","title":"Twm.is_integer/1","doc":"See  Twm.Validators.is_integer_value/1 .","ref":"Twm.html#is_integer/1"},{"type":"function","title":"Twm.is_number/1","doc":"See  Twm.Validators.is_number_value/1 .","ref":"Twm.html#is_number/1"},{"type":"function","title":"Twm.is_percent/1","doc":"See  Twm.Validators.percent?/1 .","ref":"Twm.html#is_percent/1"},{"type":"function","title":"Twm.is_tshirt_size/1","doc":"See  Twm.Validators.is_tshirt_size/1 .","ref":"Twm.html#is_tshirt_size/1"},{"type":"function","title":"Twm.merge/2","doc":"Merges multiple Tailwind CSS classes into a single string, removing conflicting classes.\n\nThis function uses an LRU cache to improve performance for repeated calls with the\nsame input classes.","ref":"Twm.html#merge/2"},{"type":"function","title":"Examples - Twm.merge/2","doc":"iex> Twm.merge(\"px-2 px-4\")\n    \"px-4\"\n\n    iex> Twm.merge(\"pt-2 pt-4 pb-3\")\n    \"pt-4 pb-3\"","ref":"Twm.html#merge/2-examples"},{"type":"module","title":"Twm.Cache","doc":"LRU (Least Recently Used) cache implementation for Twm.\n\nThis module provides caching capabilities for Tailwind class merging\noperations to improve performance by avoiding redundant operations\non the same class combinations. It also stores configuration and\nclass group utilities in ETS tables for efficient access.\n\nThis module can be used in two ways:\n\n1. As a global cache for the main Twm functionality:\n\n```\ndefmodule Twm.Application do\n  @moduledoc false\n\n  use Application\n\n  @impl true\n  def start(_type, _args) do\n    children = [\n      # Start the Twm.Cache with default configuration\n      {Twm.Cache, []}\n    ]\n\n    opts = [strategy: :one_for_one, name: Twm.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\nYou can also pass a custom cache name and configuration:\n\n```\ndefmodule Twm.Application do\n  @moduledoc false\n\n  use Application\n\n  @impl true\n  def start(_type, _args) do\n    # Custom configuration\n    custom_config = Twm.Config.extend(cache_size: 1000)\n\n    children = [\n      # Start the Twm.Cache with custom name and configuration\n      {Twm.Cache, [name: :my_twm_cache, config: custom_config]}\n    ]\n\n    opts = [strategy: :one_for_one, name: Twm.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\n2. As custom cache instances for custom merge functions:\n\n```\n# Create a custom cache with a specific size\ncache_pid = Twm.Cache.ensure_started(20, :cache_23231)\n\n# Use the cache directly\nTwm.Cache.put(cache_pid, \"key\", \"value\")\n```","ref":"Twm.Cache.html"},{"type":"function","title":"Twm.Cache.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Twm.Cache.html#child_spec/1"},{"type":"function","title":"Twm.Cache.clear/1","doc":"Clears all entries from the cache.","ref":"Twm.Cache.html#clear/1"},{"type":"function","title":"Examples - Twm.Cache.clear/1","doc":"# Start a cache server for doctest\n    iex> unique_number = Integer.to_string(:erlang.unique_integer([:positive]))\n    iex> cache_pid = Twm.Cache.ensure_started(10, String.to_atom(\"cache\" <> unique_number))\n    iex> Twm.Cache.put(cache_pid, \"key1\", \"value1\")\n    :ok\n    iex> Twm.Cache.clear(cache_pid)\n    :ok\n    iex> Twm.Cache.get(cache_pid, \"key1\")\n    :error","ref":"Twm.Cache.html#clear/1-examples"},{"type":"function","title":"Twm.Cache.ensure_started/2","doc":"Ensures a cache server is started with the given size.\n\nIf a server with the provided name already exists, it returns its pid.\nOtherwise, it starts a new server with the given cache size.","ref":"Twm.Cache.html#ensure_started/2"},{"type":"function","title":"Examples - Twm.Cache.ensure_started/2","doc":"iex> unique_number = Integer.to_string(:erlang.unique_integer([:positive]))\n    iex> cache_pid = Twm.Cache.ensure_started(100, String.to_atom(\"cache\" <> unique_number))\n    iex> Twm.Cache.put(cache_pid, \"key\", \"value\")\n    :ok\n    iex> Twm.Cache.get(cache_pid, \"key\")\n    {:ok, \"value\"}","ref":"Twm.Cache.html#ensure_started/2-examples"},{"type":"function","title":"Twm.Cache.get/2","doc":"Retrieves a value from the cache by key.\n\nReturns `{:ok, value}` if the key exists, or `:error` if it doesn't.","ref":"Twm.Cache.html#get/2"},{"type":"function","title":"Examples - Twm.Cache.get/2","doc":"# Start a cache server for doctest\n    iex> unique_number = Integer.to_string(:erlang.unique_integer([:positive]))\n    iex> cache_pid = Twm.Cache.ensure_started(10, String.to_atom(\"cache\" <> unique_number))\n    iex> Twm.Cache.put(cache_pid, \"key1\", \"value1\")\n    :ok\n    iex> Twm.Cache.get(cache_pid, \"key1\")\n    {:ok, \"value1\"}\n    iex> Twm.Cache.get(cache_pid, \"nonexistent_key\")\n    :error","ref":"Twm.Cache.html#get/2-examples"},{"type":"function","title":"Twm.Cache.get_or_create/2","doc":"Retrieves a value from the cache by key. If it is not present creates one, stores it and returns it.\n\nReturns `{:ok, value}` or `:error` if the cache doesn't exist.","ref":"Twm.Cache.html#get_or_create/2"},{"type":"function","title":"Examples - Twm.Cache.get_or_create/2","doc":"# Start a cache server for doctest\n    iex> unique_number = Integer.to_string(:erlang.unique_integer([:positive]))\n    iex> cache_pid = Twm.Cache.ensure_started(10, String.to_atom(\"cache\" <> unique_number))\n    iex> Twm.Cache.put(cache_pid, \"key1\", \"value1\")\n    :ok\n    iex> Twm.Cache.get(cache_pid, \"key1\")\n    {:ok, \"value1\"}\n    iex> Twm.Cache.get(cache_pid, \"nonexistent_key\")\n    :error","ref":"Twm.Cache.html#get_or_create/2-examples"},{"type":"function","title":"Twm.Cache.put/3","doc":"Stores a key-value pair in the cache.\n\nIf the key already exists, its value is updated and it becomes the most recently used.\nIf the cache is full, the least recently used entry is removed.","ref":"Twm.Cache.html#put/3"},{"type":"function","title":"Examples - Twm.Cache.put/3","doc":"# Start a cache server for doctest\n    iex> unique_number = Integer.to_string(:erlang.unique_integer([:positive]))\n    iex> cache_pid = Twm.Cache.ensure_started(10, String.to_atom(\"cache\" <> unique_number))\n    iex> Twm.Cache.put(cache_pid, \"key1\", \"value1\")\n    :ok\n    iex> Twm.Cache.get(cache_pid, \"key1\")\n    {:ok, \"value1\"}","ref":"Twm.Cache.html#put/3-examples"},{"type":"function","title":"Twm.Cache.resize/2","doc":"Changes the maximum capacity of the cache.\n\nIf the new size is smaller than the current number of entries,\nthe least recently used entries are removed until the cache fits\nthe new size.","ref":"Twm.Cache.html#resize/2"},{"type":"function","title":"Examples - Twm.Cache.resize/2","doc":"# Start a cache server for doctest\n    iex> unique_number = Integer.to_string(:erlang.unique_integer([:positive]))\n    iex> cache_pid = Twm.Cache.ensure_started(100, String.to_atom(\"cache\" <> unique_number))\n    iex> # Fill cache with a few entries\n    iex> Twm.Cache.put(cache_pid, \"key1\", \"value1\")\n    :ok\n    iex> Twm.Cache.put(cache_pid, \"key2\", \"value2\")\n    :ok\n    iex> Twm.Cache.resize(cache_pid, 1)\n    :ok\n    iex> Twm.Cache.size(cache_pid)\n    1","ref":"Twm.Cache.html#resize/2-examples"},{"type":"function","title":"Twm.Cache.size/1","doc":"Returns the current size of the cache.","ref":"Twm.Cache.html#size/1"},{"type":"function","title":"Examples - Twm.Cache.size/1","doc":"# Start a cache server for doctest\n    iex> unique_number = Integer.to_string(:erlang.unique_integer([:positive]))\n    iex> cache_pid = Twm.Cache.ensure_started(10, String.to_atom(\"cache\" <> unique_number))\n    iex> Twm.Cache.put(cache_pid, \"key1\", \"value1\")\n    :ok\n    iex> Twm.Cache.put(cache_pid, \"key2\", \"value2\")\n    :ok\n    iex> Twm.Cache.size(cache_pid)\n    2","ref":"Twm.Cache.html#size/1-examples"},{"type":"function","title":"Twm.Cache.start_link/1","doc":"Starts the cache server.","ref":"Twm.Cache.html#start_link/1"},{"type":"function","title":"Options - Twm.Cache.start_link/1","doc":"* `:name` - The name to register the cache process with. Defaults to `Twm.Cache`.\n* `:cache_size` - The maximum number of entries in the cache. Defaults to 500.","ref":"Twm.Cache.html#start_link/1-options"},{"type":"module","title":"Twm.ClassGroupUtils","doc":"Utilities for working with class groups in Tailwind CSS.\n\nThis module provides functions to identify which group a class belongs to\nand to determine conflicting class groups based on the configuration.\n\nUses keyword lists throughout for maintaining order.","ref":"Twm.ClassGroupUtils.html"},{"type":"type","title":"Twm.ClassGroupUtils.class_part_object/0","doc":"","ref":"Twm.ClassGroupUtils.html#t:class_part_object/0"},{"type":"type","title":"Twm.ClassGroupUtils.class_validator_object/0","doc":"","ref":"Twm.ClassGroupUtils.html#t:class_validator_object/0"},{"type":"function","title":"Twm.ClassGroupUtils.create_class_group_utils/1","doc":"Creates class group utility context based on the provided configuration.\n\nReturns a Context struct containing the necessary data for class group operations.\nThis replaces the previous approach of using anonymous functions that caused\nmemory pressure by capturing large data structures.","ref":"Twm.ClassGroupUtils.html#create_class_group_utils/1"},{"type":"function","title":"Parameters - Twm.ClassGroupUtils.create_class_group_utils/1","doc":"* `config` - Configuration keyword list containing class groups and conflicting groups","ref":"Twm.ClassGroupUtils.html#create_class_group_utils/1-parameters"},{"type":"function","title":"Examples - Twm.ClassGroupUtils.create_class_group_utils/1","doc":"iex> config = Twm.Config.new([\n    ...>   class_groups: [display: [\"block\", \"inline\"]],\n    ...>   conflicting_class_groups: [display: []],\n    ...>   conflicting_class_group_modifiers: [],\n    ...>   theme: []\n    ...> ])\n    iex> context = Twm.ClassGroupUtils.create_class_group_utils(config)\n    iex> Twm.ClassGroupUtils.get_class_group_id(\"block\", context)\n    \"display\"","ref":"Twm.ClassGroupUtils.html#create_class_group_utils/1-examples"},{"type":"function","title":"Twm.ClassGroupUtils.create_class_map/1","doc":"Creates a class map from the configuration for efficient class lookup.\n\nThe class map is a tree-like structure using keyword lists that allows for\nefficient traversal and lookup of class names and their corresponding groups.","ref":"Twm.ClassGroupUtils.html#create_class_map/1"},{"type":"function","title":"Examples - Twm.ClassGroupUtils.create_class_map/1","doc":"iex> config = Twm.Config.new([\n    ...>   class_groups: [display: [\"block\", \"inline\"]],\n    ...>   theme: []\n    ...> ])\n    iex> class_map = Twm.ClassGroupUtils.create_class_map(config)\n    iex> class_map[:next_part][:block][:class_group_id]\n    \"display\"","ref":"Twm.ClassGroupUtils.html#create_class_map/1-examples"},{"type":"function","title":"Twm.ClassGroupUtils.get_class_group_id/2","doc":"Gets the class group ID for a given class name using the context.","ref":"Twm.ClassGroupUtils.html#get_class_group_id/2"},{"type":"function","title":"Parameters - Twm.ClassGroupUtils.get_class_group_id/2","doc":"* `class_name` - The class name to look up\n  * `context` - The Context struct containing class group data","ref":"Twm.ClassGroupUtils.html#get_class_group_id/2-parameters"},{"type":"function","title":"Examples - Twm.ClassGroupUtils.get_class_group_id/2","doc":"iex> config = Twm.Config.new([class_groups: [display: [\"block\"]], theme: []])\n    iex> context = Twm.ClassGroupUtils.create_class_group_utils(config)\n    iex> Twm.ClassGroupUtils.get_class_group_id(\"block\", context)\n    \"display\"","ref":"Twm.ClassGroupUtils.html#get_class_group_id/2-examples"},{"type":"function","title":"Twm.ClassGroupUtils.get_conflicting_class_group_ids/3","doc":"Gets the conflicting class group IDs for a given class group.","ref":"Twm.ClassGroupUtils.html#get_conflicting_class_group_ids/3"},{"type":"function","title":"Parameters - Twm.ClassGroupUtils.get_conflicting_class_group_ids/3","doc":"* `class_group_id` - The class group ID to find conflicts for\n  * `has_postfix_modifier` - Whether the class has a postfix modifier\n  * `context` - The Context struct containing conflict data","ref":"Twm.ClassGroupUtils.html#get_conflicting_class_group_ids/3-parameters"},{"type":"function","title":"Examples - Twm.ClassGroupUtils.get_conflicting_class_group_ids/3","doc":"iex> config = Twm.Config.new([\n    ...>   class_groups: [display: [\"block\"]],\n    ...>   conflicting_class_groups: [display: [\"position\"]],\n    ...>   conflicting_class_group_modifiers: []\n    ...> ])\n    iex> context = Twm.ClassGroupUtils.create_class_group_utils(config)\n    iex> Twm.ClassGroupUtils.get_conflicting_class_group_ids(\"display\", false, context)\n    [\"position\"]","ref":"Twm.ClassGroupUtils.html#get_conflicting_class_group_ids/3-examples"},{"type":"module","title":"Twm.Config","doc":"Configuration management for Twm.\n\nThis module provides functions for getting and extending the configuration\nfor the Twm library.","ref":"Twm.Config.html"},{"type":"function","title":"Twm.Config.extend/1","doc":"Extends the default configuration with custom options.","ref":"Twm.Config.html#extend/1"},{"type":"function","title":"Options - Twm.Config.extend/1","doc":"* `:cache_size` - The size of the LRU cache\n  * `:prefix` - The prefix for Tailwind classes\n  * `:override` - Configuration values to override (takes precedence over default values)\n  * `:extend` - Configuration values to extend (merges with default values)","ref":"Twm.Config.html#extend/1-options"},{"type":"function","title":"Examples - Twm.Config.extend/1","doc":"iex> config = Twm.Config.extend(cache_size: 1000)\n    iex> config[:cache_size]\n    1000\n\n    iex> config = Twm.Config.extend(override: [class_groups: [display: [\"custom-display\"]]])\n    iex> config[:class_groups][:display]\n    [\"custom-display\"]\n\n    iex> config = Twm.Config.extend(extend: [class_groups: [custom_group: [\"custom-class\"]]])\n    iex> config[:class_groups][:custom_group]\n    [\"custom-class\"]","ref":"Twm.Config.html#extend/1-examples"},{"type":"function","title":"Twm.Config.extend/2","doc":"","ref":"Twm.Config.html#extend/2"},{"type":"function","title":"Twm.Config.get_default/0","doc":"Returns the default configuration for Twm.","ref":"Twm.Config.html#get_default/0"},{"type":"function","title":"Examples - Twm.Config.get_default/0","doc":"iex> config = Twm.Config.get_default()\n    iex> config[:cache_size]\n    500","ref":"Twm.Config.html#get_default/0-examples"},{"type":"function","title":"Twm.Config.new/1","doc":"","ref":"Twm.Config.html#new/1"},{"type":"type","title":"Twm.Config.t/0","doc":"Configuration for the Twm library.\n\n* `:cache_name` - Name of the LRU cache (if enabled)\n* `:prefix` - Optional prefix for Tailwind classes\n* `:theme` - Theme configuration\n* `:class_groups` - Class group definitions\n* `:conflicting_class_groups` - Groups of class names that conflict with each other\n* `:cache_size` - Size of the LRU cache (if enabled)\n* `:experimental_parse_class_name` - Optional experimental class name parser function","ref":"Twm.Config.html#t:t/0"},{"type":"function","title":"Twm.Config.validate/1","doc":"Validates a configuration keyword list.\n\nChecks if all required keys are present and the values have the correct types.","ref":"Twm.Config.html#validate/1"},{"type":"function","title":"Examples - Twm.Config.validate/1","doc":"iex> Twm.Config.validate(Twm.Config.get_default())\n    {:ok, [...]}\n\n    iex> Twm.Config.validate([])\n    {:error, \"Missing required configuration keys: cache_size, theme, class_groups, conflicting_class_groups\"}","ref":"Twm.Config.html#validate/1-examples"},{"type":"module","title":"Twm.Config.Default","doc":"Default configuration for Twm.\n\nThis module provides the default configuration for Twm, which includes:\n- Default class groups\n- Conflicting class groups\n- Theme scales","ref":"Twm.Config.Default.html"},{"type":"function","title":"Twm.Config.Default.get/0","doc":"Returns the default configuration for Twm.","ref":"Twm.Config.Default.html#get/0"},{"type":"function","title":"Examples - Twm.Config.Default.get/0","doc":"iex> config = Twm.Config.Default.get()\n    iex> config.cache_size\n    500\n    iex> \"block\" in config.class_groups.display\n    true","ref":"Twm.Config.Default.html#get/0-examples"},{"type":"module","title":"Twm.Config.Theme","doc":"Theme helper functions for Twm.\n\nThis module provides functions for working with themes in Tailwind CSS classes.\nIt converts the TypeScript `fromTheme` functions to Elixir.","ref":"Twm.Config.Theme.html"},{"type":"function","title":"Twm.Config.Theme.animate/1","doc":"Returns animate-related theme values.\n\nThis is a convenience function for the animate theme.","ref":"Twm.Config.Theme.html#animate/1"},{"type":"function","title":"Twm.Config.Theme.aspect/1","doc":"Returns aspect-related theme values.\n\nThis is a convenience function for the aspect theme.","ref":"Twm.Config.Theme.html#aspect/1"},{"type":"function","title":"Twm.Config.Theme.blur/1","doc":"Returns blur-related theme values.\n\nThis is a convenience function for the blur theme.","ref":"Twm.Config.Theme.html#blur/1"},{"type":"function","title":"Twm.Config.Theme.breakpoint/1","doc":"Returns breakpoint-related theme values.\n\nThis is a convenience function for the breakpoint theme.","ref":"Twm.Config.Theme.html#breakpoint/1"},{"type":"function","title":"Twm.Config.Theme.call_theme_getter/2","doc":"Calls a theme getter function with the provided theme configuration.\n\nThis function handles both `ThemeGetter` structs and regular functions\nfor backwards compatibility.","ref":"Twm.Config.Theme.html#call_theme_getter/2"},{"type":"function","title":"Parameters - Twm.Config.Theme.call_theme_getter/2","doc":"* `theme_getter` - A `ThemeGetter` struct or regular function\n  * `theme_config` - The theme configuration map","ref":"Twm.Config.Theme.html#call_theme_getter/2-parameters"},{"type":"function","title":"Examples - Twm.Config.Theme.call_theme_getter/2","doc":"iex> theme_spacing = Twm.Config.Theme.from_theme(:spacing)\n    iex> config = %{spacing: [\"1\", \"2\", \"4\"]}\n    iex> Twm.Config.Theme.call_theme_getter(theme_spacing, config)\n    [\"1\", \"2\", \"4\"]","ref":"Twm.Config.Theme.html#call_theme_getter/2-examples"},{"type":"function","title":"Twm.Config.Theme.color/1","doc":"Returns color-related theme values.\n\nThis is a convenience function for the color theme.","ref":"Twm.Config.Theme.html#color/1"},{"type":"function","title":"Twm.Config.Theme.container/1","doc":"Returns container-related theme values.\n\nThis is a convenience function for the container theme.","ref":"Twm.Config.Theme.html#container/1"},{"type":"function","title":"Twm.Config.Theme.drop_shadow/1","doc":"Returns drop-shadow-related theme values.\n\nThis is a convenience function for the drop-shadow theme.","ref":"Twm.Config.Theme.html#drop_shadow/1"},{"type":"function","title":"Twm.Config.Theme.ease/1","doc":"Returns ease-related theme values.\n\nThis is a convenience function for the ease theme.","ref":"Twm.Config.Theme.html#ease/1"},{"type":"function","title":"Twm.Config.Theme.font/1","doc":"Returns font-related theme values.\n\nThis is a convenience function for the font theme.","ref":"Twm.Config.Theme.html#font/1"},{"type":"function","title":"Twm.Config.Theme.font_weight/1","doc":"Returns font-weight-related theme values.\n\nThis is a convenience function for the font-weight theme.","ref":"Twm.Config.Theme.html#font_weight/1"},{"type":"function","title":"Twm.Config.Theme.from_theme/1","doc":"Creates a theme getter function for the specified theme key.\n\nThis is the Elixir equivalent of the TypeScript `fromTheme` function.\nReturns a `ThemeGetter` struct that can be identified as a theme getter\nand called to extract theme values.","ref":"Twm.Config.Theme.html#from_theme/1"},{"type":"function","title":"Parameters - Twm.Config.Theme.from_theme/1","doc":"* `theme_key` - The theme key to extract from theme configuration (string or atom)","ref":"Twm.Config.Theme.html#from_theme/1-parameters"},{"type":"function","title":"Returns - Twm.Config.Theme.from_theme/1","doc":"A `ThemeGetter` struct containing:\n  * `:key` - The theme key\n  * `:getter_fn` - Function that extracts values from theme config\n  * `:is_theme_getter` - Always `true` to mark this as a theme getter","ref":"Twm.Config.Theme.html#from_theme/1-returns"},{"type":"function","title":"Examples - Twm.Config.Theme.from_theme/1","doc":"iex> theme_spacing = Twm.Config.Theme.from_theme(\"spacing\")\n    iex> theme_spacing.is_theme_getter\n    true\n\n    iex> theme_color = Twm.Config.Theme.from_theme(:color)\n    iex> theme_color.key\n    :color\n\n    iex> theme_config = %{spacing: [\"1\", \"2\", \"4\", \"8\"]}\n    iex> theme_spacing = Twm.Config.Theme.from_theme(\"spacing\")\n    iex> Twm.Config.Theme.call_theme_getter(theme_spacing, theme_config)\n    [\"1\", \"2\", \"4\", \"8\"]\n\n    iex> theme_config = %{color: [\"red\", \"blue\"]}\n    iex> theme_missing = Twm.Config.Theme.from_theme(\"missing\")\n    iex> Twm.Config.Theme.call_theme_getter(theme_missing, theme_config)\n    []","ref":"Twm.Config.Theme.html#from_theme/1-examples"},{"type":"function","title":"Twm.Config.Theme.inset_shadow/1","doc":"Returns inset-shadow-related theme values.\n\nThis is a convenience function for the inset-shadow theme.","ref":"Twm.Config.Theme.html#inset_shadow/1"},{"type":"function","title":"Twm.Config.Theme.leading/1","doc":"Returns leading-related theme values.\n\nThis is a convenience function for the leading theme.","ref":"Twm.Config.Theme.html#leading/1"},{"type":"function","title":"Twm.Config.Theme.perspective/1","doc":"Returns perspective-related theme values.\n\nThis is a convenience function for the perspective theme.","ref":"Twm.Config.Theme.html#perspective/1"},{"type":"function","title":"Twm.Config.Theme.radius/1","doc":"Returns radius-related theme values.\n\nThis is a convenience function for the radius theme.","ref":"Twm.Config.Theme.html#radius/1"},{"type":"function","title":"Twm.Config.Theme.shadow/1","doc":"Returns shadow-related theme values.\n\nThis is a convenience function for the shadow theme.","ref":"Twm.Config.Theme.html#shadow/1"},{"type":"function","title":"Twm.Config.Theme.spacing/1","doc":"Returns spacing-related theme values.\n\nThis is a convenience function for the spacing theme.","ref":"Twm.Config.Theme.html#spacing/1"},{"type":"function","title":"Twm.Config.Theme.text/1","doc":"Returns text-related theme values.\n\nThis is a convenience function for the text theme.","ref":"Twm.Config.Theme.html#text/1"},{"type":"function","title":"Twm.Config.Theme.text_shadow/1","doc":"Returns text-shadow-related theme values.\n\nThis is a convenience function for the text-shadow theme.","ref":"Twm.Config.Theme.html#text_shadow/1"},{"type":"function","title":"Twm.Config.Theme.theme_getter?/1","doc":"Checks if a value is a theme getter.","ref":"Twm.Config.Theme.html#theme_getter?/1"},{"type":"function","title":"Examples - Twm.Config.Theme.theme_getter?/1","doc":"iex> theme_spacing = Twm.Config.Theme.from_theme(:spacing)\n    iex> Twm.Config.Theme.theme_getter?(theme_spacing)\n    true\n\n    iex> regular_func = fn x -> x end\n    iex> Twm.Config.Theme.theme_getter?(regular_func)\n    false","ref":"Twm.Config.Theme.html#theme_getter?/1-examples"},{"type":"function","title":"Twm.Config.Theme.tracking/1","doc":"Returns tracking-related theme values.\n\nThis is a convenience function for the tracking theme.","ref":"Twm.Config.Theme.html#tracking/1"},{"type":"module","title":"Twm.Config.Theme.ThemeGetter","doc":"A struct that identifies a theme key for lookup.\n\nThis replaces the anonymous function approach to eliminate memory pressure\nfrom closures in the configuration.","ref":"Twm.Config.Theme.ThemeGetter.html"},{"type":"type","title":"Twm.Config.Theme.ThemeGetter.t/0","doc":"","ref":"Twm.Config.Theme.ThemeGetter.html#t:t/0"},{"type":"module","title":"Twm.Context.ClassGroupProcessingContext","doc":"Context structure for class group processing operations.\n\nThis struct holds the configuration data needed for class group operations,\nreplacing the anonymous functions that were causing memory pressure by\ncapturing large data structures in their closures.\n\nUsed by the ClassGroupUtils module to efficiently process class groups\nand determine conflicts between classes.","ref":"Twm.Context.ClassGroupProcessingContext.html"},{"type":"type","title":"Twm.Context.ClassGroupProcessingContext.t/0","doc":"","ref":"Twm.Context.ClassGroupProcessingContext.html#t:t/0"},{"type":"module","title":"Twm.Context.ClassParsingContext","doc":"Context structure for class name parsing operations.\n\nThis struct holds the configuration data needed for class name parsing operations,\nreplacing the anonymous functions that were causing memory pressure by\ncapturing configuration data in their closures.\n\nUsed by the Parser.ClassName module to efficiently parse class names\nwith proper prefix handling and experimental parsing features.","ref":"Twm.Context.ClassParsingContext.html"},{"type":"type","title":"Twm.Context.ClassParsingContext.t/0","doc":"","ref":"Twm.Context.ClassParsingContext.html#t:t/0"},{"type":"module","title":"Twm.Context.ModifierSortingContext","doc":"Context structure for modifier sorting operations.\n\nThis struct holds the configuration data needed for modifier sorting operations,\nreplacing the anonymous functions that were causing memory pressure by\ncapturing configuration data in their closures.\n\nUsed by the SortModifiers module to efficiently sort modifiers while\npreserving the order of order-sensitive modifiers and arbitrary variants.","ref":"Twm.Context.ModifierSortingContext.html"},{"type":"type","title":"Twm.Context.ModifierSortingContext.t/0","doc":"","ref":"Twm.Context.ModifierSortingContext.html#t:t/0"},{"type":"module","title":"Twm.Merger","doc":"Handles the core class merging logic for Twm.\n\nThis module provides functions to merge Tailwind CSS classes, handling conflicts\nbased on the provided configuration.","ref":"Twm.Merger.html"},{"type":"function","title":"Twm.Merger.merge_classes/3","doc":"Merges Tailwind CSS classes based on the provided configuration.\n\nThis function takes a string of space-separated class names and merges them\naccording to the Tailwind CSS conflict resolution rules defined in the configuration.","ref":"Twm.Merger.html#merge_classes/3"},{"type":"function","title":"Examples - Twm.Merger.merge_classes/3","doc":"iex> config = Twm.Config.get_default()\n    iex> Twm.Merger.merge_classes(\"px-2 px-4\", config)\n    \"px-4\"\n\n    iex> config = Twm.Config.get_default()\n    iex> Twm.Merger.merge_classes(\"pt-2 pt-4 pb-3\", config)\n    \"pt-4 pb-3\"","ref":"Twm.Merger.html#merge_classes/3-examples"},{"type":"module","title":"Twm.Parser.ClassName","doc":"Provides functionality for parsing Tailwind CSS class names into their components.\n\nThis module is responsible for breaking down class names into their modifiers,\nbase class name, and handling special cases like the important modifier.","ref":"Twm.Parser.ClassName.html"},{"type":"function","title":"Twm.Parser.ClassName.create_parse_class_name/1","doc":"Creates a context for parsing class names based on the provided configuration.","ref":"Twm.Parser.ClassName.html#create_parse_class_name/1"},{"type":"function","title":"Parameters - Twm.Parser.ClassName.create_parse_class_name/1","doc":"* `config` - A keyword list containing configuration options like prefix and experimental parser","ref":"Twm.Parser.ClassName.html#create_parse_class_name/1-parameters"},{"type":"function","title":"Returns - Twm.Parser.ClassName.create_parse_class_name/1","doc":"* A Context struct containing the parsing configuration","ref":"Twm.Parser.ClassName.html#create_parse_class_name/1-returns"},{"type":"function","title":"Twm.Parser.ClassName.do_parse_class_name/1","doc":"Parse a class name into its constituent parts.\n\nInspired by `splitAtTopLevelOnly` used in Tailwind CSS.\nSee: https://github.com/tailwindlabs/tailwindcss/blob/v3.2.2/src/util/splitAtTopLevelOnly.js","ref":"Twm.Parser.ClassName.html#do_parse_class_name/1"},{"type":"function","title":"Parameters - Twm.Parser.ClassName.do_parse_class_name/1","doc":"* `class_name` - The class name string to parse","ref":"Twm.Parser.ClassName.html#do_parse_class_name/1-parameters"},{"type":"function","title":"Returns - Twm.Parser.ClassName.do_parse_class_name/1","doc":"* A map containing the parsed components of the class name","ref":"Twm.Parser.ClassName.html#do_parse_class_name/1-returns"},{"type":"function","title":"Twm.Parser.ClassName.parse_class_name/2","doc":"Parses a class name using the provided context.","ref":"Twm.Parser.ClassName.html#parse_class_name/2"},{"type":"function","title":"Parameters - Twm.Parser.ClassName.parse_class_name/2","doc":"* `class_name` - The class name string to parse\n* `context` - The Context struct containing parsing configuration","ref":"Twm.Parser.ClassName.html#parse_class_name/2-parameters"},{"type":"function","title":"Returns - Twm.Parser.ClassName.parse_class_name/2","doc":"* A map containing the parsed components of the class name","ref":"Twm.Parser.ClassName.html#parse_class_name/2-returns"},{"type":"function","title":"Twm.Parser.ClassName.strip_important_modifier/1","doc":"Removes the important modifier from a class name.\n\nIn Tailwind CSS, the important modifier can be at the end of the class name,\nor at the beginning in v3.","ref":"Twm.Parser.ClassName.html#strip_important_modifier/1"},{"type":"function","title":"Parameters - Twm.Parser.ClassName.strip_important_modifier/1","doc":"* `base_class_name` - The class name to process","ref":"Twm.Parser.ClassName.html#strip_important_modifier/1-parameters"},{"type":"function","title":"Returns - Twm.Parser.ClassName.strip_important_modifier/1","doc":"* The class name without the important modifier","ref":"Twm.Parser.ClassName.html#strip_important_modifier/1-returns"},{"type":"module","title":"Twm.SortModifiers","doc":"Sorts modifiers according to following schema:\n- Predefined modifiers are sorted alphabetically\n- When an arbitrary variant appears, it must be preserved which modifiers are before and after it","ref":"Twm.SortModifiers.html"},{"type":"function","title":"Twm.SortModifiers.create_sort_modifiers/1","doc":"Creates a context for sorting modifiers based on the provided configuration.\n\nThe context holds the configuration data needed for modifier sorting operations.","ref":"Twm.SortModifiers.html#create_sort_modifiers/1"},{"type":"function","title":"Parameters - Twm.SortModifiers.create_sort_modifiers/1","doc":"* `config` - A keyword list containing the `order_sensitive_modifiers` key","ref":"Twm.SortModifiers.html#create_sort_modifiers/1-parameters"},{"type":"function","title":"Returns - Twm.SortModifiers.create_sort_modifiers/1","doc":"A Context struct containing the sorting configuration.","ref":"Twm.SortModifiers.html#create_sort_modifiers/1-returns"},{"type":"function","title":"Examples - Twm.SortModifiers.create_sort_modifiers/1","doc":"iex> config = Twm.Config.new([order_sensitive_modifiers: [\"hover\", \"focus\"]])\n    iex> context = Twm.SortModifiers.create_sort_modifiers(config)\n    iex> Twm.SortModifiers.sort_modifiers([\"d\", \"hover\", \"c\"], context)\n    [\"d\", \"hover\", \"c\"]\n\n    iex> config = Twm.Config.new([order_sensitive_modifiers: [\"hover\"]])\n    iex> context = Twm.SortModifiers.create_sort_modifiers(config)\n    iex> Twm.SortModifiers.sort_modifiers([\"[data-test]\", \"d\", \"c\"], context)\n    [\"[data-test]\", \"c\", \"d\"]","ref":"Twm.SortModifiers.html#create_sort_modifiers/1-examples"},{"type":"function","title":"Twm.SortModifiers.sort_modifiers/2","doc":"Sorts a list of modifiers using the provided context.","ref":"Twm.SortModifiers.html#sort_modifiers/2"},{"type":"function","title":"Parameters - Twm.SortModifiers.sort_modifiers/2","doc":"* `modifiers` - List of modifier strings to sort\n  * `context` - Context struct containing sorting configuration","ref":"Twm.SortModifiers.html#sort_modifiers/2-parameters"},{"type":"function","title":"Returns - Twm.SortModifiers.sort_modifiers/2","doc":"A sorted list of modifiers.","ref":"Twm.SortModifiers.html#sort_modifiers/2-returns"},{"type":"function","title":"Examples - Twm.SortModifiers.sort_modifiers/2","doc":"iex> config = Twm.Config.new([order_sensitive_modifiers: [\"hover\"]])\n    iex> context = Twm.SortModifiers.create_sort_modifiers(config)\n    iex> Twm.SortModifiers.sort_modifiers([\"d\", \"hover\", \"c\"], context)\n    [\"d\", \"hover\", \"c\"]","ref":"Twm.SortModifiers.html#sort_modifiers/2-examples"},{"type":"module","title":"Twm.Types","doc":"Common types used throughout the Twm library.","ref":"Twm.Types.html"},{"type":"type","title":"Twm.Types.parsed_class_name/0","doc":"Represents a parsed class name with its components.\n\n* `:modifiers` - List of modifiers applied to the class (e.g., \"hover\", \"focus\", \"dark\")\n* `:has_important_modifier` - Boolean indicating if the class has the important modifier\n* `:base_class_name` - The core class name without modifiers\n* `:maybe_postfix_modifier_position` - Position of a postfix modifier if present\n* `:is_external` - Whether the class is external to Tailwind (when prefix doesn't match)","ref":"Twm.Types.html#t:parsed_class_name/0"},{"type":"module","title":"Twm.Validators","doc":"Provides functions for validating Tailwind CSS class values.\n\nPort of the TypeScript validators in tailwind-merge.","ref":"Twm.Validators.html"},{"type":"function","title":"Twm.Validators.any?/0","doc":"Always returns true. Used for validators that accept any value.","ref":"Twm.Validators.html#any?/0"},{"type":"function","title":"Twm.Validators.any?/1","doc":"","ref":"Twm.Validators.html#any?/1"},{"type":"function","title":"Twm.Validators.is_any_non_arbitrary/1","doc":"Returns true if the value is not an arbitrary value or variable.","ref":"Twm.Validators.html#is_any_non_arbitrary/1"},{"type":"function","title":"Twm.Validators.is_arbitrary_image/1","doc":"Returns true if the value is an arbitrary image (e.g., \"[url:var(--my-url)]\").","ref":"Twm.Validators.html#is_arbitrary_image/1"},{"type":"function","title":"Twm.Validators.is_arbitrary_length/1","doc":"Returns true if the value is an arbitrary length (e.g., \"[10px]\").","ref":"Twm.Validators.html#is_arbitrary_length/1"},{"type":"function","title":"Twm.Validators.is_arbitrary_number/1","doc":"Returns true if the value is an arbitrary number (e.g., \"[10]\").","ref":"Twm.Validators.html#is_arbitrary_number/1"},{"type":"function","title":"Twm.Validators.is_arbitrary_position/1","doc":"Returns true if the value is an arbitrary position (e.g., \"[position:center]\").","ref":"Twm.Validators.html#is_arbitrary_position/1"},{"type":"function","title":"Twm.Validators.is_arbitrary_shadow/1","doc":"Returns true if the value is an arbitrary shadow (e.g., \"[0_35px_60px_-15px_rgba(0,0,0,0.3)]\").","ref":"Twm.Validators.html#is_arbitrary_shadow/1"},{"type":"function","title":"Twm.Validators.is_arbitrary_size/1","doc":"Returns true if the value is an arbitrary size (e.g., \"[size:10px]\").","ref":"Twm.Validators.html#is_arbitrary_size/1"},{"type":"function","title":"Twm.Validators.is_arbitrary_value/1","doc":"Returns true if the value is an arbitrary value (e.g., \"[value]\").","ref":"Twm.Validators.html#is_arbitrary_value/1"},{"type":"function","title":"Twm.Validators.is_arbitrary_variable/1","doc":"Returns true if the value is an arbitrary variable (e.g., \"(variable)\").","ref":"Twm.Validators.html#is_arbitrary_variable/1"},{"type":"function","title":"Twm.Validators.is_arbitrary_variable_family_name/1","doc":"Returns true if the value is an arbitrary variable family name (e.g., \"(family-name:var(--font))\").","ref":"Twm.Validators.html#is_arbitrary_variable_family_name/1"},{"type":"function","title":"Twm.Validators.is_arbitrary_variable_image/1","doc":"Returns true if the value is an arbitrary variable image (e.g., \"(image:var(--img))\").","ref":"Twm.Validators.html#is_arbitrary_variable_image/1"},{"type":"function","title":"Twm.Validators.is_arbitrary_variable_length/1","doc":"Returns true if the value is an arbitrary variable length (e.g., \"(length:var(--size))\").","ref":"Twm.Validators.html#is_arbitrary_variable_length/1"},{"type":"function","title":"Twm.Validators.is_arbitrary_variable_position/1","doc":"Returns true if the value is an arbitrary variable position (e.g., \"(position:var(--pos))\").","ref":"Twm.Validators.html#is_arbitrary_variable_position/1"},{"type":"function","title":"Twm.Validators.is_arbitrary_variable_shadow/1","doc":"Returns true if the value is an arbitrary variable shadow (e.g., \"(shadow:var(--shadow))\").","ref":"Twm.Validators.html#is_arbitrary_variable_shadow/1"},{"type":"function","title":"Twm.Validators.is_arbitrary_variable_size/1","doc":"Returns true if the value is an arbitrary variable size (e.g., \"(size:var(--size))\").","ref":"Twm.Validators.html#is_arbitrary_variable_size/1"},{"type":"function","title":"Twm.Validators.is_fraction/1","doc":"Returns true if the value is a fraction (e.g., \"1/2\").","ref":"Twm.Validators.html#is_fraction/1"},{"type":"function","title":"Twm.Validators.is_integer_value/1","doc":"Returns true if the value is an integer.","ref":"Twm.Validators.html#is_integer_value/1"},{"type":"function","title":"Twm.Validators.is_number_value/1","doc":"Returns true if the value is a number.","ref":"Twm.Validators.html#is_number_value/1"},{"type":"function","title":"Twm.Validators.is_tshirt_size/1","doc":"Returns true if the value is a t-shirt size (e.g., \"xs\", \"sm\", \"md\", \"lg\", \"xl\", \"2xl\").","ref":"Twm.Validators.html#is_tshirt_size/1"},{"type":"function","title":"Twm.Validators.percent?/1","doc":"Returns true if the value is a percentage.","ref":"Twm.Validators.html#percent?/1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}